import type { TypeCacheConfig } from '../Type/index.js';
import type { CacheInterface } from './CacheInterface.js';
/**
 * Interface representing a cache factory.
 */
export interface CacheFactoryInterface<TypeConfig extends TypeCacheConfig = TypeCacheConfig> {
    /**
     * Creates an cache based on the provided configuration.
     *
     * @param {TypeConfig} config - The configuration object for the cache provider.
     * @returns {Promise<CacheInterface>} - An cache provider instance.
     * @throws {Error} - Throws an error when requested provider cache can't be created.
     */
    createCache(config: TypeConfig): Promise<CacheInterface>;
}
